JointSpectrum
=============

.. currentmodule:: spdcalc.spdcalc

.. autoclass:: JointSpectrum
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~JointSpectrum.jsa
      ~JointSpectrum.jsa_normalized
      ~JointSpectrum.jsa_normalized_range
      ~JointSpectrum.jsa_range
      ~JointSpectrum.jsi
      ~JointSpectrum.jsi_normalized
      ~JointSpectrum.jsi_normalized_range
      ~JointSpectrum.jsi_range
      ~JointSpectrum.jsi_singles
      ~JointSpectrum.jsi_singles_normalized
      ~JointSpectrum.jsi_singles_normalized_range
      ~JointSpectrum.jsi_singles_range
      ~JointSpectrum.schmidt_number

   .. rubric:: Methods Documentation

   .. automethod:: jsa
   .. automethod:: jsa_normalized
   .. automethod:: jsa_normalized_range
   .. automethod:: jsa_range
   .. automethod:: jsi
   .. automethod:: jsi_normalized
   .. automethod:: jsi_normalized_range
   .. automethod:: jsi_range
   .. automethod:: jsi_singles
   .. automethod:: jsi_singles_normalized
   .. automethod:: jsi_singles_normalized_range
   .. automethod:: jsi_singles_range
   .. automethod:: schmidt_number
